package com.persagy.transfer.task;

import com.persagy.transfer.service.PersagyDbService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.PropertySource;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * @description: 同步设备数据到万达数据库
 * @author: YangWanYi
 * @create: 2021-09-16 11:28
 **/
@Component
@Slf4j
@PropertySource("classpath:/configuration.properties")
public class SycnEquDataToWdTask {

    private int times;

    @Autowired
    private PersagyDbService persagyDbService;

    /**
     * 数据同步逻辑
     */
    @Scheduled(cron = "${sycnData2wdTaskCron:*/15 * * * * ?}")
    public void execute() {
        log.info("定时任务：开始同步设备信息到万达数据库，类限定名:com.persagy.transfer.task.SycnEquDataToWdTask，thread id:{},FixedPrintTask execute times:{}", Thread.currentThread().getId(), ++times);
        try {
            this.persagyDbService.syncData2WD();
        } catch (Exception e) {
            e.printStackTrace();
            log.info("定时任务：同步设备信息到万达数据库处理失败，类限定名:com.persagy.transfer.task.SycnEquDataToWdTask，thread id:{},msg:{},error:{}", Thread.currentThread().getId(), e.getMessage(), e.getStackTrace());
        }
    }
}
